[libc-commits] [libc] dc72be4 - [libc][Obvious] Fix few typos in tests.

Siva Chandra Reddy via libc-commits libc-commits at lists.llvm.org
Tue Jun 23 13:18:45 PDT 2020


Author: Siva Chandra Reddy
Date: 2020-06-23T13:11:41-07:00
New Revision: dc72be4e0130675833c56d4d72e22a56872876ea

URL: https://github.com/llvm/llvm-project/commit/dc72be4e0130675833c56d4d72e22a56872876ea
DIFF: https://github.com/llvm/llvm-project/commit/dc72be4e0130675833c56d4d72e22a56872876ea.diff

LOG: [libc][Obvious] Fix few typos in tests.

Added: 
    

Modified: 
    libc/test/src/math/ceilf_test.cpp
    libc/test/src/math/floorf_test.cpp
    libc/test/src/math/frexpf_test.cpp
    libc/test/src/math/modff_test.cpp
    libc/test/src/math/roundf_test.cpp
    libc/test/src/math/truncf_test.cpp

Removed: 
    


################################################################################
diff  --git a/libc/test/src/math/ceilf_test.cpp b/libc/test/src/math/ceilf_test.cpp
index 7bfb2ac15b6a..3db004e65542 100644
--- a/libc/test/src/math/ceilf_test.cpp
+++ b/libc/test/src/math/ceilf_test.cpp
@@ -52,7 +52,7 @@ TEST(CeilfTest, SpecialNumbers) {
                                       valueFromBits(BitPatterns::negZero))));
 }
 
-TEST(ceilfTest, RoundedNumbers) {
+TEST(CeilfTest, RoundedNumbers) {
   EXPECT_EQ(valueAsBits(1.0f), valueAsBits(__llvm_libc::ceilf(1.0f)));
   EXPECT_EQ(valueAsBits(-1.0f), valueAsBits(__llvm_libc::ceilf(-1.0f)));
   EXPECT_EQ(valueAsBits(10.0f), valueAsBits(__llvm_libc::ceilf(10.0f)));
@@ -61,7 +61,7 @@ TEST(ceilfTest, RoundedNumbers) {
   EXPECT_EQ(valueAsBits(-12345.0f), valueAsBits(__llvm_libc::ceilf(-12345.0f)));
 }
 
-TEST(ceilfTest, InFloatRange) {
+TEST(CeilfTest, InFloatRange) {
   using BitsType = Properties::BitsType;
   constexpr BitsType count = 1000000;
   constexpr BitsType step = UINT32_MAX / count;

diff  --git a/libc/test/src/math/floorf_test.cpp b/libc/test/src/math/floorf_test.cpp
index c25014da1257..1e05dcfccd1d 100644
--- a/libc/test/src/math/floorf_test.cpp
+++ b/libc/test/src/math/floorf_test.cpp
@@ -52,7 +52,7 @@ TEST(FloorfTest, SpecialNumbers) {
                                       valueFromBits(BitPatterns::negZero))));
 }
 
-TEST(floorfTest, RoundedNumbers) {
+TEST(FloorfTest, RoundedNumbers) {
   EXPECT_EQ(valueAsBits(1.0f), valueAsBits(__llvm_libc::floorf(1.0f)));
   EXPECT_EQ(valueAsBits(-1.0f), valueAsBits(__llvm_libc::floorf(-1.0f)));
   EXPECT_EQ(valueAsBits(10.0f), valueAsBits(__llvm_libc::floorf(10.0f)));
@@ -62,7 +62,7 @@ TEST(floorfTest, RoundedNumbers) {
             valueAsBits(__llvm_libc::floorf(-12345.0f)));
 }
 
-TEST(floorfTest, InFloatRange) {
+TEST(FloorfTest, InFloatRange) {
   using BitsType = Properties::BitsType;
   constexpr BitsType count = 1000000;
   constexpr BitsType step = UINT32_MAX / count;

diff  --git a/libc/test/src/math/frexpf_test.cpp b/libc/test/src/math/frexpf_test.cpp
index e15f384ea28b..3b82c68078ee 100644
--- a/libc/test/src/math/frexpf_test.cpp
+++ b/libc/test/src/math/frexpf_test.cpp
@@ -1,5 +1,4 @@
-//===-- Unittests for frexpf
-//-----------------------------------------------===//
+//===-- Unittests for frexpf ----------------------------------------------===//
 //
 // Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 // See https://llvm.org/LICENSE.txt for license information.

diff  --git a/libc/test/src/math/roundf_test.cpp b/libc/test/src/math/roundf_test.cpp
index 88c746b126ef..ae8008a0340f 100644
--- a/libc/test/src/math/roundf_test.cpp
+++ b/libc/test/src/math/roundf_test.cpp
@@ -62,7 +62,7 @@ TEST(RoundfTest, RoundedNumbers) {
             valueAsBits(__llvm_libc::roundf(-12345.0f)));
 }
 
-TEST(RoundTest, CloseToZeroNumbers) {
+TEST(RoundfTest, CloseToZeroNumbers) {
   EXPECT_EQ(valueAsBits(1.0f), valueAsBits(__llvm_libc::roundf(0.5f)));
   EXPECT_EQ(valueAsBits(-1.0f), valueAsBits(__llvm_libc::roundf(-0.5f)));
   EXPECT_EQ(valueAsBits(0.0f), valueAsBits(__llvm_libc::roundf(0.115f)));

diff  --git a/libc/test/src/math/truncf_test.cpp b/libc/test/src/math/truncf_test.cpp
index 90fc84a5b5f9..2ace51632af7 100644
--- a/libc/test/src/math/truncf_test.cpp
+++ b/libc/test/src/math/truncf_test.cpp
@@ -53,7 +53,7 @@ TEST(TruncfTest, SpecialNumbers) {
                                       valueFromBits(BitPatterns::negZero))));
 }
 
-TEST(TruncTest, RoundedNumbers) {
+TEST(TruncfTest, RoundedNumbers) {
   EXPECT_EQ(valueAsBits(1.0f), valueAsBits(__llvm_libc::truncf(1.0f)));
   EXPECT_EQ(valueAsBits(-1.0f), valueAsBits(__llvm_libc::truncf(-1.0f)));
   EXPECT_EQ(valueAsBits(10.0f), valueAsBits(__llvm_libc::truncf(10.0f)));
@@ -63,7 +63,7 @@ TEST(TruncTest, RoundedNumbers) {
             valueAsBits(__llvm_libc::truncf(-12345.0f)));
 }
 
-TEST(truncfTest, InFloatRange) {
+TEST(TruncfTest, InFloatRange) {
   using BitsType = Properties::BitsType;
   constexpr BitsType count = 1000000;
   constexpr BitsType step = UINT32_MAX / count;


        


More information about the libc-commits mailing list
diff  --git a/libc/test/src/math/modff_test.cpp b/libc/test/src/math/modff_test.cpp
index fbd3b86f163a..66244b8ac892 100644
--- a/libc/test/src/math/modff_test.cpp
+++ b/libc/test/src/math/modff_test.cpp
@@ -1,5 +1,4 @@
 //===-- Unittests for modfff
 //-----------------------------------------------===//
 //
 // Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 // See https://llvm.org/LICENSE.txt for license information.
@@ -89,7 +88,7 @@ TEST(ModffTest, Integers) {
   EXPECT_EQ(valueAsBits(integral), valueAsBits(-12345.0f));
 }
 
-TEST(ModfTest, Fractions) {
+TEST(ModffTest, Fractions) {
   float integral;
 
   EXPECT_EQ(valueAsBits(0.5f),
@@ -1,5 +1,4 @@
-//===-- Unittests for modfff
-//-----------------------------------------------===//
+//===-- Unittests for modff -----------------------------------------------===//
 //
 // Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
